==> 0.0.2.tar.gz: ios/Classes/AdManager/YFAdsRewardVideoManager.m <==
//
//  yfRewardVideoAdManager.m
//  Runner
//
//  Created by 陈刚 on 2021/4/15.
//

#import <Foundation/Foundation.h>
#import "YFAdsRewardVideoManager.h"
#import "YFAdsConstant.h"
#import <Flutter/Flutter.h>
#import "YFAdsUtils.h"
#import <YFAdsSDK/YFAdRewardVideo.h>

@interface YFAdsRewardVideoManager () <YFAdRewardVideoDelegate>

@property (nonatomic, strong) YFAdRewardVideo *rewardVideo;
@property (nonatomic, strong) UIViewController *viewController;
@property (nonatomic, strong) FlutterEventSink flutterEventSink;

@end

@implementation YFAdsRewardVideoManager

- (instancetype)initWithParams:(FlutterEventSink)flutterEventSink viewController:(FlutterViewController *)viewController{
    self = [super init];
    _viewController = viewController;
    _flutterEventSink = flutterEventSink;
    return self;
}

- (void)showAd:(NSDictionary *)parametersDic {
    NSString *positionId = parametersDic[KEY_POSITION_ID];
    
    self.rewardVideo = [[YFAdRewardVideo alloc] initWithAdUnitID:positionId viewController:self.viewController];
    self.rewardVideo.delegate = self;
    NSString *userId = parametersDic[KEY_REWARD_USER_ID];
    if(userId){
        _rewardVideo.userId = userId;
    }
//    _rewardVideo.rewardName = parametersDic[KEY_REWARD_NAME];
//    NSString *rewardAmountStr = parametersDic[KEY_REWARD_AMOUNT];
//    if(![rewardAmountStr isEqual: [NSNull null]]){
//        _rewardVideo.rewardAmount = [rewardAmountStr integerValue];
//    }
    NSString *extra = parametersDic[KEY_REWARD_EXTRA];
    if(extra){
        _rewardVideo.extra = extra;
    }
    [self.rewardVideo loadAndShowAd];
}

//-(void)showAdNow{
//    if (_rewardVideo.isReady) {
//        [_rewardVideo showAd:_viewController];
//    } else {
//        NSLog(@"WH激励视频未准备好");
//    }
//}
//

//
///// 激励视频下载成功
//- (void)WHRewardVideoAdVideoDidLoad:(WHRewardVideoAd *)rewardVideoAd {
//    NSLog(@"WH激励视频下载成功");
////    NSMutableDictionary *result = @{KEY_METHOD:@"WHRewardVideoAdVideoDidLoad"};
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"WHRewardVideoAdVideoDidLoad" forKey:KEY_METHOD];
//    [self callBack:result];
//}
//

///// 激励视频展示失败
//- (void)WHRewardedVideoAdShowFail:(WHRewardVideoAd * _Nullable)rewardVideoAd didFailWithError:(NSError * _Nullable)error {
//    NSLog(@"WH激励视频展示失败 %@", error);
////    NSMutableDictionary *result = @{KEY_METHOD:@"WHRewardedVideoAdShowFail",KEY_ERROR:error.localizedDescription};
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"WHRewardedVideoAdShowFail" forKey:KEY_METHOD];
//    [result setValue:error.localizedDescription forKey:KEY_ERROR];
//    [self callBack:result];
//    //    [SVProgressHUD showInfoWithStatus:[NSString stringWithFormat:@"[%ld]%@", (long)error.code, error.localizedDescription]];
//}

///// 激励视频点击跳过
//- (void)WHRewardedVideoAdDidClickSkip:(WHRewardVideoAd *)rewardedVideoAd {
//    NSLog(@"WH激励视频已跳过");
////    NSMutableDictionary *result = @{KEY_METHOD:@"WHRewardedVideoAdDidClickSkip"};
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"WHRewardedVideoAdDidClickSkip" forKey:KEY_METHOD];
//    [self callBack:result];
//}
//


-(void)callBack:(NSMutableDictionary *)resultDic{
    [resultDic setValue:AD_TYPE_REWARD_VIDEO forKey:KEY_AD_TYPE];
    NSString * result = [YFAdsUtils dictionary2JsonString:resultDic];
    _flutterEventSink(result);
}


- (void)loadAndShowAd{
    [self deallocAd];
   
}

- (void)deallocAd {
    self.rewardVideo.delegate = nil;
    self.rewardVideo = nil;
}

/// 广告数据加载成功
- (void)fcAdLoadSuccess:(YFAdBaseAdapter *)model {
    NSLog(@"广告数据拉取成功 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"WHRewardedVideoAdDidLoad" forKey:KEY_METHOD];
    [self callBack:result];
}


/// 视频缓存成功
- (void)fcAdRewardVideoOnAdVideoCached
{
    NSLog(@"视频缓存成功 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"WHRewardVideoAdVideoDidLoad" forKey:KEY_METHOD];
    [self callBack:result];
}

/// 到达激励时间
- (void)fcAdRewardVideoAdDidRewardEffective {
    NSLog(@"到达激励时间 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"WHRewardedVideoAdDidRewardEffective" forKey:KEY_METHOD];
    [result setValue:@"YES" forKey:KEY_RESULT_REWARD_VERIFY];
    [result setValue:@"" forKey:KEY_RESULT_REWARD_INFO];
    [self callBack:result];
    
}

/// 广告曝光
- (void)fcAdExposured:(id)adapter  {
    NSLog(@"广告曝光回调 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfRewardedVideoAdDidShow" forKey:KEY_METHOD];
    [self callBack:result];
}

/// 广告点击
- (void)fcAdClicked:(id)adapter  {
    NSLog(@"广告点击 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfRewardedVideoAdDidClick" forKey:KEY_METHOD];
    [self callBack:result];
}

/// 广告加载失败
- (void)fcAdFailedWithError:(NSError *)error description:(NSDictionary *)description{
    NSLog(@"广告展示失败 %s  error: %@ 详情:%@", __func__, error,description);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfRewardedVideoAd" forKey:KEY_METHOD];
    [self callBack:result];
    [self deallocAd];
}

/// 广告关闭
- (void)fcAdDidClose:(id)adapter  {
    NSLog(@"广告关闭了 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfRewardedVideoAdDidClose" forKey:KEY_METHOD];
    [self callBack:result];
    [self deallocAd];
}

/// 播放完成
- (void)fcAdRewardVideoAdDidPlayFinish {
    NSLog(@"播放完成 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfRewardedVideoAdDidPlayFinish" forKey:KEY_METHOD];
    [self callBack:result];
}


-(void)dealloc {
    NSLog(@"激励视频释放 %s", __func__);
}

@end

==> 0.0.4.tar.gz: ios/Classes/AdManager/YFAdsRewardVideoManager.m <==
//
//  yfRewardVideoAdManager.m
//  Runner
//
//  Created by 陈刚 on 2021/4/15.
//

#import <Foundation/Foundation.h>
#import "YFAdsRewardVideoManager.h"
#import "YFAdsConstant.h"
#import <Flutter/Flutter.h>
#import "YFAdsUtils.h"
#import <YFAdsSDK/YFAdRewardVideo.h>

@interface YFAdsRewardVideoManager () <YFAdRewardVideoDelegate>

@property (nonatomic, strong) YFAdRewardVideo *rewardVideo;
@property (nonatomic, strong) UIViewController *viewController;
@property (nonatomic, strong) FlutterEventSink flutterEventSink;

@end

@implementation YFAdsRewardVideoManager

- (instancetype)initWithParams:(FlutterEventSink)flutterEventSink viewController:(FlutterViewController *)viewController{
    self = [super init];
    _viewController = viewController;
    _flutterEventSink = flutterEventSink;
    return self;
}

- (void)showAd:(NSDictionary *)parametersDic {
    NSString *positionId = parametersDic[KEY_POSITION_ID];
    
    self.rewardVideo = [[YFAdRewardVideo alloc] initWithAdUnitID:positionId viewController:self.viewController];
    self.rewardVideo.delegate = self;
    NSString *userId = parametersDic[KEY_REWARD_USER_ID];
    if(userId){
        _rewardVideo.userId = userId;
    }
//    _rewardVideo.rewardName = parametersDic[KEY_REWARD_NAME];
//    NSString *rewardAmountStr = parametersDic[KEY_REWARD_AMOUNT];
//    if(![rewardAmountStr isEqual: [NSNull null]]){
//        _rewardVideo.rewardAmount = [rewardAmountStr integerValue];
//    }
    NSString *extra = parametersDic[KEY_REWARD_EXTRA];
    if(extra){
        _rewardVideo.extra = extra;
    }
    [self.rewardVideo loadAndShowAd];
}

//-(void)showAdNow{
//    if (_rewardVideo.isReady) {
//        [_rewardVideo showAd:_viewController];
//    } else {
//        NSLog(@"WH激励视频未准备好");
//    }
//}
//

//
///// 激励视频下载成功
//- (void)WHRewardVideoAdVideoDidLoad:(WHRewardVideoAd *)rewardVideoAd {
//    NSLog(@"WH激励视频下载成功");
////    NSMutableDictionary *result = @{KEY_METHOD:@"WHRewardVideoAdVideoDidLoad"};
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"WHRewardVideoAdVideoDidLoad" forKey:KEY_METHOD];
//    [self callBack:result];
//}
//

///// 激励视频展示失败
//- (void)WHRewardedVideoAdShowFail:(WHRewardVideoAd * _Nullable)rewardVideoAd didFailWithError:(NSError * _Nullable)error {
//    NSLog(@"WH激励视频展示失败 %@", error);
////    NSMutableDictionary *result = @{KEY_METHOD:@"WHRewardedVideoAdShowFail",KEY_ERROR:error.localizedDescription};
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"WHRewardedVideoAdShowFail" forKey:KEY_METHOD];
//    [result setValue:error.localizedDescription forKey:KEY_ERROR];
//    [self callBack:result];
//    //    [SVProgressHUD showInfoWithStatus:[NSString stringWithFormat:@"[%ld]%@", (long)error.code, error.localizedDescription]];
//}

///// 激励视频点击跳过
//- (void)WHRewardedVideoAdDidClickSkip:(WHRewardVideoAd *)rewardedVideoAd {
//    NSLog(@"WH激励视频已跳过");
////    NSMutableDictionary *result = @{KEY_METHOD:@"WHRewardedVideoAdDidClickSkip"};
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"WHRewardedVideoAdDidClickSkip" forKey:KEY_METHOD];
//    [self callBack:result];
//}
//


-(void)callBack:(NSMutableDictionary *)resultDic{
    [resultDic setValue:AD_TYPE_REWARD_VIDEO forKey:KEY_AD_TYPE];
    NSString * result = [YFAdsUtils dictionary2JsonString:resultDic];
    _flutterEventSink(result);
}


- (void)loadAndShowAd{
    [self deallocAd];
   
}

- (void)deallocAd {
    self.rewardVideo.delegate = nil;
    self.rewardVideo = nil;
}

/// 广告数据加载成功
- (void)fcAdLoadSuccess:(YFAdBaseAdapter *)model {
    NSLog(@"广告数据拉取成功 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfRewardedVideoAdDidLoad" forKey:KEY_METHOD];
    [self callBack:result];
}


/// 视频缓存成功
- (void)fcAdRewardVideoOnAdVideoCached
{
    NSLog(@"视频缓存成功 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfRewardVideoAdVideoDidLoad" forKey:KEY_METHOD];
    [self callBack:result];
}

/// 到达激励时间
- (void)fcAdRewardVideoAdDidRewardEffective {
    NSLog(@"到达激励时间 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfRewardedVideoAdDidRewardEffective" forKey:KEY_METHOD];
    [result setValue:@"YES" forKey:KEY_RESULT_REWARD_VERIFY];
    [result setValue:@"" forKey:KEY_RESULT_REWARD_INFO];
    [self callBack:result];
    
}

/// 广告曝光
- (void)fcAdExposured:(id)adapter  {
    NSLog(@"广告曝光回调 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfRewardedVideoAdDidShow" forKey:KEY_METHOD];
    [self callBack:result];
}

/// 广告点击
- (void)fcAdClicked:(id)adapter  {
    NSLog(@"广告点击 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfRewardedVideoAdDidClick" forKey:KEY_METHOD];
    [self callBack:result];
}

/// 广告加载失败
- (void)fcAdFailedWithError:(NSError *)error description:(NSDictionary *)description{
    NSLog(@"广告展示失败 %s  error: %@ 详情:%@", __func__, error,description);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfRewardedVideoAd" forKey:KEY_METHOD];
    [self callBack:result];
    [self deallocAd];
}

/// 广告关闭
- (void)fcAdDidClose:(id)adapter  {
    NSLog(@"广告关闭了 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfRewardedVideoAdDidClose" forKey:KEY_METHOD];
    [self callBack:result];
    [self deallocAd];
}

/// 播放完成
- (void)fcAdRewardVideoAdDidPlayFinish {
    NSLog(@"播放完成 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfRewardedVideoAdDidPlayFinish" forKey:KEY_METHOD];
    [self callBack:result];
}


-(void)dealloc {
    NSLog(@"激励视频释放 %s", __func__);
}

@end
